package com.someco.scripts;

import java.util.HashMap;
import java.util.Map;

import javax.transaction.UserTransaction;

import org.alfresco.repo.security.authentication.AuthenticationUtil;
import org.alfresco.service.cmr.workflow.WorkflowService;
import org.alfresco.service.transaction.TransactionService;
import org.alfresco.web.scripts.WebScriptRequest;
import org.alfresco.web.scripts.Status;
import org.apache.log4j.Logger;

/**
 * This is the controller for the review.get web script.
 * 
 * @author jpotts 
 */
public class GetReview extends org.alfresco.web.scripts.DeclarativeWebScript {

	Logger logger = Logger.getLogger(GetReview.class);
			
	// Dependencies
	private WorkflowService workflowService;
	private TransactionService transactionService;

	@Override
	protected Map<String, Object> executeImpl(WebScriptRequest req, Status status) {
		
		//String email = req.getParameter("email");
		String id = req.getParameter("id");
		String action = req.getParameter("action");
		//String secret = req.getParameter("s");

		if (id == null || action == null) {
			logger.debug("Email, ID, action, or secret not set");
			status.setCode(Status.STATUS_BAD_REQUEST, "Required data has not been provided");
		}
		
		boolean switchUser = false;
		
		String currentUser = AuthenticationUtil.getCurrentUserName();
		if (currentUser != null && !currentUser.equals("admin")) {
			logger.debug("Current user is not admin so switching to admin");
			AuthenticationUtil.setCurrentUser("admin");
			switchUser = true;
		}
        
		UserTransaction txn = transactionService.getUserTransaction();

		Map<String, Object> model = new HashMap<String, Object>();
		
		try {
			txn.begin();
			logger.debug("About to signal id:" + id + " with transition:" + action);
			
			workflowService.signal(id, action);
			logger.debug("Signal sent.");	

			model.put("response", "Success");

			txn.commit();

		} catch(Throwable e) {
			try {
				if (txn.getStatus() == javax.transaction.Status.STATUS_ACTIVE) txn.rollback();
			} catch (Throwable ee) {
				e.printStackTrace();
			}
		}
		
		if (switchUser) AuthenticationUtil.setCurrentUser(currentUser);
		logger.debug("Leaving Rating.create()");
		
		return model;
	}

	public WorkflowService getWorkflowService() {
		return workflowService;
	}

	public void setWorkflowService(WorkflowService workflowService) {
		this.workflowService = workflowService;
	}
	
	public void setTransactionService(TransactionService transactionService) {
		this.transactionService = transactionService;
	}
	
}
